import { Component, LegacyRef } from 'react';
import { NativeEventEmitter, NativeMethods, ViewStyle } from 'react-native';

export interface FluentAdFlowWidgetProps {
  style?: ViewStyle; // Optional style, with height being part of it
  params?: any; // Parameters for the widget
  onAdShow?: (isVisible: boolean) => void; // Callback when ad visibility changes
  wrapperName?: string; // Name of the wrapper package
  wrapperVersion?: string; // Version of the wrapper package
}

export interface FluentAdFlowWidgetState {
  height: number; // Current height of the widget
  viewId: string; // Unique ID for the widget instance
  isParamsSet: boolean; // Flag indicating if parameters are set
}

// Define FluentAdFlowWidgetView as a class component
export declare class FluentAdFlowWidgetView extends Component<
  FluentAdFlowWidgetProps,
  FluentAdFlowWidgetState
> {
  constructor(props: FluentAdFlowWidgetProps);

  /**
   * Set parameters for the widget.
   * @param params - Parameters to set for the widget instance.
   */
  setParams(params: any): void;

  /**
   * Renders the widget component.
   */
  render(): JSX.Element;
}

// Native component definition using `requireNativeComponent`
export declare const WidgetNativeComponent: (
  props: FluentAdFlowWidgetProps,
  ref: LegacyRef<Component<FluentAdFlowWidgetProps> & Readonly<NativeMethods>>
) => JSX.Element;

// Native event emitter and manager
export declare const eventManagerEmitter: NativeEventEmitter;
export declare const FluentAdFlowSdkManager: {
  initSdk(apiKey: string, referrer?: string): Promise<void>;
  setParams(viewId: string, params: any): void;
};

// Export the component as the default export
export default FluentAdFlowWidgetView;
